/*====================================================================
Project: Early Childhood Development and School-Age Performance
Authors: Marina Bassi, Bruno Besbas, Lelys Dinarte, 
		 Saravana Ravindran and Ana Reynoso
----------------------------------------------------------------------
Modification Date: 09 Jan 2024
 
Do-file: Juan Fernando Duque-Giraldo    
====================================================================*/

qui{
// Load data
	use "${data}\data_EL.dta", clear

// Add variable labels
	do "${dofiles}\DICIPE_VarLabels.do"

*-------------------------------------------------------------------------------*
*									TABLE 2										*
*-------------------------------------------------------------------------------*
// Table 2: First Stage & ITT Impacts on Primary School Enrollment

	glo if "if istarget35==1"

	** Westfall & Young P-Values
	local vars "wenttopreschl enroledatschool schl_repetition_uncon app_grade1 enrolment_zi"
	wyoung `vars', cmd(areg OUTCOMEVAR treatment_ecd [pw=${wgt}] ${if}, absorb(DIST_ID) vce(cluster COM_ID)) ///
		familyp(treatment_ecd) bootstraps(${reps}) seed(123) strata(DIST_ID) cluster(COM_ID) /*singlestep detail*/
	mat mat 	 = r(table)[1...,4]
	mat rown mat = `vars'
	matlist mat

	eststo clear
	local k = 1
	local vars "wenttopreschl enroledatschool schl_repetition_uncon app_grade1 enrolment_zi"
	foreach var in `vars'{
		local pval = mat[`k',1]
		qui eststo r`k': areg `var' treatment_ecd [pw=${wgt}] ${if}, absorb(DIST_ID) vce(cluster COM_ID)
		qui sum 		`var' ${if} & treatment_ecd==0
		eststo r`k': estadd scalar ctrl_mean = r(mean)
		eststo r`k': estadd scalar ctrl_sd 	= r(sd)
		eststo r`k': estadd matrix wy = `pval'
		local k = `k'+1
	}
}

// OUTPUT TABLE
	glo title "Table 2: First Stage & ITT Impacts on Primary School Enrollment"
	glo notes "Notes: *** p < 0.01, ** p < 0.05, * p < 0.10. OLS estimates at the target child-level are presented using school outcomes reported by the caregiver at endline. Standard errors clustered at the community level are shown in parentheses. All regressions include district fixed effects. Westfall and Young (1993) p-values are shown in square brackets, where 10,000 replications were used. The primary school enrollment index is constructed over columns (2) to (4) following Kling et al. (2007). Estimates are weighted to give each community an equal weight in the analysis. Covariates are not included in the regressions."

	esttab, cells( b(star fmt(3)) se(par fmt(3)) wy(par([ ]) fmt(3)) ) label varlabels(c1 " ") nogaps noconstant nobaselevels scalars("ctrl_mean Mean control") sfmt(3) star(* 0.10 ** 0.05 *** 0.01) interaction(" * ") title("${title}") replace addnotes("${notes}") nonotes compress
