/*====================================================================
Project: Early Childhood Development and School-Age Performance
Authors: Marina Bassi, Bruno Besbas, Lelys Dinarte, 
		 Saravana Ravindran and Ana Reynoso
----------------------------------------------------------------------
Modification Date: 12 Feb 2024
 
Do-file: Juan Fernando Duque-Giraldo    
====================================================================*/

// Load data
	use "${data}\data_EL.dta", clear

// Add variable labels
	do "${dofiles}\DICIPE_VarLabels.do"

// Figure 2: Nonparametric Distributions of the Primary School
	la var ageinmonthatEL "Age in months at Endline"
	loc var "enrolment_zi"
	loc lbl: variable label `var'
	glo and "& ageinmonthatEL<=99 & ageinmonthatEL>73 & istarget35==1"
	tw 	(lpolyci `var' ageinmonthatEL if treatment_ecd==1 ${and}, ciplot(rarea) color(%25) nofit) ///
		(lpolyci `var' ageinmonthatEL if treatment_ecd==0 ${and}, ciplot(rarea) color(%25) nofit) ///
		(lpoly 	 `var' ageinmonthatEL if treatment_ecd==1 ${and}, lcolor(navy)) ///
		(lpoly 	 `var' ageinmonthatEL if treatment_ecd==0 ${and}, lcolor(green) lpattern(dash)),  ylabel(#5, angle(h) format(%9.1f)) xlabel(#10) ytitle("`lbl'") xtitle("Age in months at Endline") graphregion(color(white)) legend(position(6) order(1 "95% CI" 3 "Treatment" 4 "Control") rows(1) region(style(none)))
	*graph export "${svdir}\DistributionMoz_primary_enrollment_index.png", as(png) replace
/*
Notes: The figure plots nonparametric distributions of the primary school enrollment index by treatment
status. 95% confidence intervals are shown. The distributions were generated using kernel-weighted local
polynomial smoothing. The primary school enrollment index was constructed over the variables "currently
enrolled at primary school", "repeated grade," and "appropriate grade for age" following Kling et al. (2007)
*/

ksmirnov enrolment_zi, by(treatment)