/*====================================================================
Project: Early Childhood Development and School-Age Performance
Authors: Marina Bassi, Bruno Besbas, Lelys Dinarte, 
		 Saravana Ravindran and Ana Reynoso
----------------------------------------------------------------------
Modification Date: 12 Feb 2024
 
Do-file: Juan Fernando Duque-Giraldo    
====================================================================*/
qui{
// Load data
	use "${data}\data_EL.dta", clear

// Add variable labels
	do "${dofiles}\DICIPE_VarLabels.do"

// Estimating coefficients
	glo if "if istarget35==1"

	eststo clear
	local k = 1
	local vars "Preliteracy_zi Premath_zi Executive_funct_zi Socioemo_cogn_zi Fine_motor_zi literacyinterest_zi skills_zi"
	foreach var in `vars'{
		qui eststo r`k': areg `var' treatment_ecd [pw=${wgt}] ${if}, absorb(DIST_ID) vce(cluster COM_ID)
		qui sum 		  `var' ${if} & treatment_ecd==0
		eststo r`k': estadd scalar ctrl_mean = r(mean)
		eststo r`k': estadd scalar ctrl_sd 	= r(sd)
		local k = `k'+1
	}

// Export results to matrix
	qui esttab, /*se*/ ci nostar
	matrix C = r(coefs)
	*matrix S = r(stats)

	eststo dir

	* Option 3
	matlist C
	mat c = C[1..1,1...]
	matlist c
	mat b = [ c[1,1] \ c[1,4] \ c[1,7] \ c[1,10] \ c[1,13] \ c[1,16] \ c[1,19] ]
	mat ci_l = [ c[1,2] \ c[1,5] \ c[1,8] \ c[1,11] \ c[1,14] \ c[1,17] \ c[1,20] ]
	mat ci_u = [ c[1,3] \ c[1,6] \ c[1,9] \ c[1,12] \ c[1,15] \ c[1,18] \ c[1,21] ]

	mat R = [b, ci_l, ci_u]
	mat coln R = b ll ul
	mat R = R'
	matlist R
}
// Figure 3: ITT Impacts on Child Cognitive and Social-Emotional Skills
	coefplot matrix(R), ci((2 3)) lwidth(medium) scheme(white_jet) xline(0) coeflabels(r1="Early Literacy Skills (index)" r2="Early Math Skills (index)" r3="Executive Function (index)" r4="Social-Emotional Development (index)" r5="Fine Motor Skill for Writing (index)" r6="Literacy interest (index)" r7="Skills index") 

	*graph export "${out}\coeffs_skills_tab3.png", width(1600) height(1200) replace

/*
Notes: This figure presents ITT estimates on the target child's cognitive and social-emotional skills. The
circles and corresponding solid lines represent the point estimates and 95% confidence intervals. OLS es-
timates at the target child-level are presented using outcomes collected at endline. Standard errors are
clustered at the community level. Estimates are expressed in standard deviation units of control group. All
regressions include district fixed effects. The skills index is constructed over the six sub-indices following
Kling et al. (2007). Estimates are weighted to give each community an equal weight in the analysis. Covari-
ates are not included in the regressions.
*/