/*====================================================================
Project: Early Childhood Development and School-Age Performance
Authors: Marina Bassi, Bruno Besbas, Lelys Dinarte, 
		 Saravana Ravindran and Ana Reynoso
----------------------------------------------------------------------
Modification Date: 09 Jan 2024
 
Do-file: Juan Fernando Duque-Giraldo    
====================================================================*/
qui{
// Load data
	use "${data}\dframe_indices.dta", clear
	
// Add variable labels
	do "${dofiles}\DICIPE_VarLabels.do"

// Labels and variable
	la var enrolment_zi "Primary School Enrollment Index"
	la var skills_zi "Skills Index"

	loc va "wenttopreschl"
	glo lbl: variable label `va'
	dis "${lbl}"

*-------------------------------------------------------------------------------*
*								MAKING TABLES									*
*-------------------------------------------------------------------------------*
// Table 3: Conditional Average Treatment Effect: Went to Preschool
	ttest tau_hat_`va', by(rank_`va')

	* Empty matrices
	mat rs = J(1,5,.)
	mat coln rs = weak strong diff pval n
	gen rank = (rank_`va'=="Strong")
	gen weak = (rank_`va'=="Weak")

	loc treat "rank"
	loc vars "tau_hat_`va' female calc_age zhfa_35_BL score_com_zi score_grossmotor_zi score_finemotor_zi score_pbmsolving_zi score_socioperso_zi speaks_port_resp_BL noschooling_resp_BL educ_resp_BL illiterate_resp_BL stimul_index_BL AF05 nbr_children_BL nbr_children35_BL C01_BL wealth_index_BL"
	foreach v in `vars'{
		ttest `v', by(`treat')
		loc N = r(N_2) + r(N_1)
		glo N = r(N_2) + r(N_1)
		loc dif = r(mu_1)-r(mu_2)
		mat r = [r(mu_1), r(mu_2), `dif',r(p), `N']
		mat rown r = `v'
		mat rs = [rs \ r]
	}
	mat res = rs
	mat res = res[2..., 1...]
	matlist res

	mat result = res[1...,1..4] // drop obs column
	matlist result
}
// OUTPUT TABLE
	glo title "Table 3: Conditional Average Treatment Effect: ${lbl}"
	glo notes "Notes: The table reports the descriptive statistics of target children in the bottom 50% (column 1) and top 50% (column 2) of the predicted Conditional Average Treatment Effect (CATE) on preschool attendance. Column 3 reports the difference between column 1 and 2. Column 4 shows the p-value of the t-test adjusted for multiple hypothesis testing."

	frmttable, statmat(result) sdec(3,3,3,3) ///
		ctitles("","(1)","(2)","(3)","(4)" \ ///
				"", "Low Predicted CATE", "High Predicted CATE", "Diff.","p-value" \ ///
				"Variable","","", "(1)-(2)", "(1)-(2)") ///
		rtitles("Conditional Average Treatment Effect (CATE)" \ ///
				"Female (\%)" \ ///
				"Age (years)" \ ///
				"Height-for-age z-score" \ ///
				"ASQ Communication" \ ///
				"ASQ Gross Motor Coordination" \ ///
				"ASQ Fine Motor Coordination" \ ///
				"ASQ Problem Solving" \ ///
				"ASQ Socio-personal"  \ ///
				"Caregiver: Speaks Portuguese (\%)" \ ///
				"Caregiver: No schooling (\%)" \ ///
				"Caregiver: Years of schooling" \ ///
				"Caregiver: Is illiterate (\%)" \ ///
				"Stimulation Index (Activities with children)" \ ///
				"Household Size" \ ///
				"Number of children aged 0-18 in Household" \ ///
				"Number of children aged 3-5 in Household" \ ///
				"Household receives remittances" \ ///
				"Wealth index of household" \ ///
				"") ///
		addrows("Observations" "${N}") ///
		nocenter tex fragment replace hlines(0{0};1{0}1) ///
		pretext("${title}") ///
		posttext("${notes}")
