/*====================================================================
Project: Early Childhood Development and School-Age Performance
Authors: Marina Bassi, Bruno Besbas, Lelys Dinarte, 
		 Saravana Ravindran and Ana Reynoso
----------------------------------------------------------------------
Modification Date: 20 Feb 2024
 
Do-file: Juan Fernando Duque-Giraldo    
====================================================================*/
qui{
// Load data
	use "${data}\data_EL.dta", clear
	
// Add variable labels
	do "${dofiles}\DICIPE_VarLabels.do"

// Getting database and matrix to tabulate
	destring PROV_ID POSTO_ID COM_ID, replace
	unique PROV_ID DIST_ID POSTO_ID COM_ID

	keep PROV_ID DIST_ID POSTO_ID COM_ID treatment_ecd target_35
	bysort COM_ID: egen clustersize35 = total(target_35)
	lab var clustersize35 "Number of traget children 3-5 selected in the community"
	bysort COM_ID: gen equal_weights = (1/clustersize35)
	drop target_35
	duplicates drop
	unique PROV_ID DIST_ID POSTO_ID COM_ID

	tempfile treated_community
	save `treated_community'

	keep PROV_ID DIST_ID COM_ID treatment_ecd clustersize35 equal_weights
	duplicates drop
	unique PROV_ID DIST_ID  COM_ID
	tempfile treated_community2
	save `treated_community2'

	** Pre-school data
	use "${data}\DICIPE Endline Escolinha.dta", clear

	keep prov_id dist_id posto_id com_nome li_loc n_anim roster_count n_anim gender* educ_class* startworking* facil_status_* init_training* init_training_num* serv_training* serv_training_days* enrollement* attendance comp_type* comp_amount comp_freq /*all items under eqmpt_infstrct*/ list_eqmpt blackboard chalk paper pen drawingbook cardgame buildingblocks fantasygame educgame storybook music playground water endtime

	duplicates drop
	gen PROV_ID = prov_id
	gen DIST_ID = dist_id
	gen POSTO_ID = posto_id
	gen COM_ID = com_nome
	drop prov_id dist_id posto_id com_nome
	order PROV_ID DIST_ID POSTO_ID COM_ID
	unique PROV_ID DIST_ID POSTO_ID COM_ID
	duplicates tag PROV_ID DIST_ID POSTO_ID COM_ID, gen(d)
	sort PROV_ID DIST_ID POSTO_ID COM_ID
	*br if d>0

	tab n_anim, m
	tab1 educ_class*, m
	tab1 startworking*, m // dates
	tab1 facil_status_*, m

	* Generate weigths following the same idea... use weigths in the regressions
	* Merge with treatment_ecd only

	merge m:1 PROV_ID DIST_ID POSTO_ID COM_ID using `treated_community', keep(1 3) gen(_m1)
	merge m:1 PROV_ID DIST_ID COM_ID using `treated_community2', update
	drop if _merge==2
	tab _merge _m1, m
	tab treatment_ecd, m

	// KEEP only treatment group for table A1
	keep if treatment_ecd==1
	count

	la var n_anim "How many facilitators do you currently have in this Little School?"
	la var enrollement_2019 "How many children are/are not enrolled in school in 2019?"
	la var enrollement_2018 "How many children are/are not enrolled in school in 2018?"
	la var attendance "On average, on a typical day, how many children come to school?"

	la var blackboard "The school has blackboard"
	la var chalk "The school has chalk"
	la var paper "The school has notebooks or writing paper"
	la var pen "The school has Pens/Pencils"
	la var drawingbook "The school has Drawing Books/Cards"
	la var cardgame "The school has Card Games"
	la var buildingblocks "The school has building blocks"
	la var fantasygame "The school has Fantasy/Pretend Games (Dolls, stuffed animals, dress-up clothes, etc.)"
	la var educgame "The school has Educational Games or Mathematics Materials (bottle caps, dice, beads, etc.)"
	la var storybook "The school has Storybooks (Books with pictures and text)"
	la var music "The school has musical instruments"
	la var playground "The school has Playground with swing, ladder, or ramp/slide"
	la var water "The school has Potable water"

	glo wgt "equal_weights" // equal_weights schl_weight pop_weight

	local vars "n_anim enrollement_2019 enrollement_2018 attendance blackboard chalk paper pen drawingbook cardgame buildingblocks fantasygame educgame storybook music playground water"
	tabstat `vars', s(mean sd count min max) long columns(statistics) save
	mat school = r(StatTotal)'

	*-------------------------------------------------------------------------------
	** Facilitators
	drop enrollement_2019 enrollement_2018 attendance blackboard chalk paper pen drawingbook cardgame buildingblocks fantasygame educgame storybook music playground water
	gen school = _n
	reshape long name_ gender_ educ_classe_ facil_status_ init_training_ init_training_num_ init_training_o_ serv_training_ serv_training_days_ startworking_, j(facilitator) i(PROV_ID DIST_ID POSTO_ID COM_ID li_loc n_anim roster_count school)
	drop li_loc
	drop if gender_==.
	dropmiss, force
	*drop _est*

	// Verify number of facilitators per school
	duplicates report PROV_ID DIST_ID POSTO_ID COM_ID school facilitator
	bys PROV_ID DIST_ID POSTO_ID COM_ID school: egen count = count(facilitator)
	compare count n_anim // CHECKED
	drop count

	recode educ_classe_ (-8=.)
	tab educ_classe_, m // "What was the highest class facilitator attended?"
	la var educ_classe_ "Facilitator: Years of schooling"
	recode facil_status_ (-8=.) (-7=.)
	la def facil_status_4 1"Teach only in the preschool" 2"Teach at preschool and primary school" 4"Teach at preschool and has another job", modify //-7"Other"
	tab facil_status_, m gen(status) // What is ${name}'s status as a facilitator?
	la var status1 "Teach only in the preschool"
	la var status2 "Teach at preschool and primary school"
	la var status3 "Teach at preschool and has another job"

	* Days working at the preschool
	*startworking "When did facilitator start working at Escolinha?"
	gen int_date = dofc(endtime)
	format int_date %td
	gen 	days_working = int_date-startworking
	replace days_working = . if days_working<0
	gen 	months_working = round(days_working/30)
	*br endtime startworking int_date days_working months_working
	la var days_working "Days working in the preschool (up to day of interview)"
	la var months_working "Months working in the preschool (up to day of interview)"

	*init_training	 Before starting to teach in the classroom, did ${name} have any training for the role of facilitator? If so, how many days did it last?
	la var init_training_num "Training days before to teach in the classrom" //How many days of training?
	tab init_training_num_

	*local vars "educ_classe_ status1 status2 status3 months_working"
	local vars "educ_classe_ status3"
	tabstat `vars', s(mean sd count min max) long columns(statistics) save
	mat facilitators = r(StatTotal)'

	matlist school
	matlist facilitators

	mat res = [ J(1,5,.) \ school[1..4,1...] \ J(1,5,.) \ school[5..17,1...] \ J(1,5,.) \ facilitators]
	matlist res

	mat results = res[1..., 1..3]
}
*-------------------------------------------------------------------------------*
*									TABLE A1									*
*-------------------------------------------------------------------------------*
// Table A1: Preschool and Facilitator Summary Statistics (Endline - Treatment Only)

glo title "Table A1: Preschool and Facilitator Summary Statistics (Endline - Treatment Only)"
glo notes "Notes: This table displays summary statistics for key characteristics of the preschool (including equipment and infrastructure) and facilitators as measured at endline for the treatment group only."

frmttable, statmat(results) sdec(3,3,0) ///
	ctitles("","(1)","(2)","(3)" \ ///
			"Variable","Mean","SD","N") ///
	rtitles("Panel A. School characteristics" \ ///
			"   Number of instructors" \ ///
			"   Enrollment in 2019 (Number of children)" \ ///
			"   Enrollment in 2018 (Number of children)" \ ///
			"   Daily attendance (Number of children)" \ ///
			"Panel B. School equipment and infrastructure. Presence of:" \ ///
			"   Blackboard" \ ///
			"   Chalks" \ ///
			"   Notebooks or writing paper" \ ///
			"   Pens/Pencils" \ ///
			"   Drawing Books/Cards" \ ///
			"   Card Games"  \ ///
			"   Building blocks" \ ///
			"   Fantasy/Pretend Games (Dolls, stuffed animals, dress-up clothes, etc.)" \ ///
			"   Educational Games or Mathematics Materials" \ ///
			"   Storybooks (Books with pictures and text)" \ ///
			"   Musical instruments" \ ///
			"   Playground with swing, ladder, or ramp/slide" \ ///
			"   Potable water" \ ///
			"Panel C. Facilitators characteristics" \ ///
			"   Years of schooling" \ ///
			"   Teach at preschool and has another job") ///
	nocenter tex fragment replace hlines(0{0};1{0}1) ///
	pretext("${title}") ///
	posttext("${notes}")