/*====================================================================
Project: Early Childhood Development and School-Age Performance
Authors: Marina Bassi, Bruno Besbas, Lelys Dinarte, 
		 Saravana Ravindran and Ana Reynoso
----------------------------------------------------------------------
Modification Date: 27 Nov 2023
 
Do-file: Juan Fernando Duque-Giraldo    
====================================================================*/
qui{
// Load data
	use "${data}\data_BL.dta", clear

// Imputation and estimation
	* Control list
	glo hh "stimul_index AF05 C01 wealth_index"
	glo caregiver "speaks_port educ_resp"
	glo child "female IDADE zhfa_35 ${c_ind}"
	glo ctrls ${child} ${caregiver} ${hh}

	tab treatment_ecd if target_35, m

	* Missing imputation of controls with global mean (according to group)
	tabmiss ${ctrls}

	**According to group
	foreach x in C01{
		qui sum `x' if HH_tag==1
		gen 	`x'_ = `x'
		replace `x'_ = r(mean) if `x'==.
		local l: variable label `x'
		la var `x'_ "`l'"
	}
	foreach x in educ_resp speaks_port{
		qui sum `x' if CH01_35==MemberId 
		gen 	`x'_ = `x'
		replace `x'_ = r(mean) if `x'==.
		local l: variable label `x'
		la var `x'_ "`l'"
	}
	foreach x in IDADE zhfa_35{
		qui sum `x' if target_35==1
		gen 	`x'_ = `x'
		replace `x'_ = r(mean) if `x'==.
		local l: variable label `x'
		la var `x'_ "`l'"
	}
	glo hh "stimul_index AF05 C01_ wealth_index"
	glo caregiver "speaks_port_ educ_resp_"
	glo child "female IDADE_ zhfa_35_ ${c_ind}"
	glo ctrls ${child} ${caregiver} ${hh}

	foreach x of global ctrls{
		mata: s = ("c.", "`x'", "#treatment_ecd")
		*mata: invtokens(s)
		mata: st_local("new", invtokens(s,""))
		dis "`new'"
		local int_ctrls `int_ctrls' `new'
	}
	glo int_ctrls `int_ctrls'
	dis "${int_ctrls}"

	tabmiss ${ctrls}

	tab attrition_hh attrition_target

	glo if "if target_35==1"
	* attrition_target
	eststo r1: areg attrition_target treatment_ecd 						 [pw=${wgt}] ${if}, a(DIST_ID) vce(cluster COM_ID)
	qui sum attrition_target [aw=${wgt}] ${if} & treatment_ecd==0 & e(sample)==1
	eststo r1: estadd scalar ctrl_mean = r(mean)
	qui test //  F-test of joint significance pvalue
	eststo r1: estadd scalar Fp = r(p)

	eststo r2: areg attrition_target treatment_ecd ${ctrls} ${int_ctrls} [pw=${wgt}] ${if}, a(DIST_ID) vce(cluster COM_ID)
	qui test ${ctrls}
	eststo r2: estadd scalar Fp1 = r(p)
	qui test AF05 wealth_index ${caregiver} ${child} // excluding remittances variables
	eststo r2: estadd scalar F2 = r(F)
	eststo r2: estadd scalar Fp2 = r(p)

	* attrition_hh
	eststo r3: areg attrition_hh treatment_ecd 						 [pw=${wgt}] ${if}, a(DIST_ID) vce(cluster COM_ID) 
	qui sum attrition_hh [aw=${wgt}] ${if} & treatment_ecd==0 & e(sample)==1
	eststo r3: estadd scalar ctrl_mean = r(mean)
	qui test //  F-test of joint significance pvalue
	eststo r3: estadd scalar Fp = r(p)

	eststo r4: areg attrition_hh treatment_ecd ${ctrls} ${int_ctrls} [pw=${wgt}] ${if}, a(DIST_ID) vce(cluster COM_ID)
	qui test ${ctrls}
	eststo r4: estadd scalar Fp1 = r(p)
	qui test AF05 wealth_index ${caregiver} ${child} // excluding remittances variables
	eststo r4: estadd scalar F2 = r(F)
	eststo r4: estadd scalar Fp2 = r(p)
}
*-------------------------------------------------------------------------------*
*									TABLE A3									*
*-------------------------------------------------------------------------------*

// Table A3: Balance in Attrition Rates across Treated and Control Individuals
la var treatment_ecd "Treatment"
// OUTPUT TABLE
glo title "Table A3: Balance in Attrition Rates across Treated and Control Individuals"
glo notes "Notes: *** p < 0.01, ** p < 0.05, * p < 0.10. OLS estimates are presented and standard errors clustered at the community level are shown in parentheses. All regressions include district fixed effects. 'Child test score attrition' is a dummy variable equal to 1 if we could not conduct the child test with the target child at endline. 'Household interview attrition' is a dummy variable equal to 1 if we could not conduct the household interview at endline. Estimates are weighted to give each community an equal weight in the analysis. Covariates are not included in the regressions."

esttab r1 r3, b(3) se(3) label nogaps noconstant nobaselevels scalars("ctrl_mean Mean control") interaction(" X ") title("${title}") star(* 0.10 ** 0.05 *** 0.01) replace mtitles("Child test score Attrition $ \beta/se $ " "Household interview Attrition $ \beta/se $ ") addnotes("${notes}")
