/*====================================================================
Project: Early Childhood Development and School-Age Performance
Authors: Marina Bassi, Bruno Besbas, Lelys Dinarte, 
		 Saravana Ravindran and Ana Reynoso
----------------------------------------------------------------------
Modification Date: 09 Feb 2024
 
Do-file: Juan Fernando Duque-Giraldo    
====================================================================*/
qui{
// Load data
	use "${data}\data_EL.dta", clear
	
// Add variable labels
	do "${dofiles}\DICIPE_VarLabels.do"

*-------------------------------------------------------------------------------*
*									TABLE A5									*
*-------------------------------------------------------------------------------*
// Table A5: LATE Impacts on Primary School Enrollment
	glo if "if istarget35==1"
	eststo clear
	local k = 1
	local vars "enroledatschool schl_repetition_uncon app_grade1 enrolment_zi"
	foreach var in `vars'{
		*qui eststo r`k': areg `var' treatment_ecd [pw=${wgt}] ${if}, absorb(DIST_ID) vce(cluster COM_ID)
		qui ivregress 2sls `var' i.DIST_ID (treatment_ecd = wenttopreschl) [pw=${wgt}] ${if}, vce(cluster COM_ID)
		*ivreg2 `var' i.DIST_ID (treatment_ecd = wenttopreschl) [pw=${wgt}] ${if}, cluster(COM_ID)
		qui sum 		`var' ${if} & treatment_ecd==0
		eststo r`k': estadd scalar ctrl_mean = r(mean)
		eststo r`k': estadd scalar ctrl_sd 	= r(sd)
		eststo r`k': estadd local fe = "Yes"
		eststo r`k': estadd local ct = "No"
		local k = `k'+1
	}
}
// OUTPUT TABLE
	la var treatment_ecd "Enrolled at pres"
	glo title "Table A5: LATE Impacts on Primary School Enrollment"
	glo notes "Notes: *** p < 0.01, ** p < 0.05, * p < 0.10. IV estimates using two-stage least squares at the target child-level are presented using school outcomes reported by the caregiver at endline. We instrument for 'Enrolled at preschool' using the treatment assignment. Standard errors clustered at the community level are shown in parentheses. All regressions include district fixed effects. The primary school enrollment index is constructed over columns (2) to (4) following Kling et al. (2007). Estimates are weighted to give each community an equal weight in the analysis. Covariates are not included in the regressions."

	esttab, b(3) se(3) label nogaps nobaselevels scalars("ctrl_mean Mean control") star(* 0.10 ** 0.05 *** 0.01) title("${title}") replace addnotes("${notes}") drop(*DIST_ID _cons)