/*====================================================================
Project: Early Childhood Development and School-Age Performance
Authors: Marina Bassi, Bruno Besbas, Lelys Dinarte, 
		 Saravana Ravindran and Ana Reynoso
----------------------------------------------------------------------
Modification Date: 09 Feb 2024
 
Do-file: Juan Fernando Duque-Giraldo    
====================================================================*/
qui{
// Load data
	use "${data}\data_EL.dta", clear
	
// Add variable labels
	do "${dofiles}\DICIPE_VarLabels.do"

*-------------------------------------------------------------------------------*
*									TABLE A6									*
*-------------------------------------------------------------------------------*
// Table A6: LATE Impacts on Child Cognitive and Social-Emotional Skills
	glo if "if istarget35==1"
	eststo clear
	local k = 1
	local vars "Preliteracy_zi Premath_zi Executive_funct_zi Socioemo_cogn_zi Fine_motor_zi literacyinterest_zi skills_zi"
	foreach var in `vars'{
		*qui eststo r`k': areg `var' treatment_ecd [pw=${wgt}] ${if}, absorb(DIST_ID) vce(cluster COM_ID)
		qui ivregress 2sls `var' i.DIST_ID (treatment_ecd = wenttopreschl) [pw=${wgt}] ${if}, vce(cluster COM_ID)
		qui sum 		  `var' ${if} & treatment_ecd==0
		eststo r`k': estadd scalar ctrl_mean = r(mean)
		eststo r`k': estadd scalar ctrl_sd 	= r(sd)
		eststo r`k': estadd local fe = "Yes"
		eststo r`k': estadd local ct = "No"
		local k = `k'+1
	}
}
// OUTPUT TABLE
	la var treatment_ecd "Enrolled at preschool"
	glo title "Table A6: LATE Impacts on Child Cognitive and Social-Emotional Skills"
	glo notes "Notes: *** p < 0.01, ** p < 0.05, * p < 0.10. IV estimates using two-stage least squares at the target child-level are presented using outcomes collected at endline. We instrument for 'Enrolled at preschool' using the treatment assignment. Standard errors clustered at the community level are shown in parentheses. Estimates are expressed in standard deviation units of control group. All regressions include district fixed effects. The skills index is constructed over columns (1) to (6) following Kling et al. (2007). Estimates are weighted to give each community an equal weight in the analysis. Covariates are not included in the regressions."

	esttab, b(3) se(3) label nogaps nobaselevels scalars("ctrl_mean Mean control") sfmt(3) star(* 0.10 ** 0.05 *** 0.01)  title("${title}") replace addnotes("${notes}") compress drop(*DIST_ID _cons)